# בדיקות והתקנת הפרוייקט
## בדוק שיש לך את הגירסא המעודכנת של pip
Windows
```
pip install --upgrade pip
```

Linux/MAC OS
```
python3 -m pip install --upgrade pip
```


## התקנת הפרוייקט
Windows
```
pip install yemot-flow
```

Linux/MAC OS
```
python3 -m pip install yemot-flow
```
## מבנה הפרוייקט
```
yemot-flow
│   README.md
│   setup.py
│   requirements.txt
│
└───yemot_flow
│   │   __init__.py
│   │   yemot_flow.py
│   │   yemot_flow_test.py
│   │
│   └───data
│       │   data.csv
│       │   data.json
│       │   data.xml
│
└───tests
    │   test_yemot_flow.py
```

# הפרוייקט יעודכן בתקופה הקרובה באופן שוטף אז תתעדכנו






### References
https://f2.freeivr.co.il/post/